MCD inheritance
TRISTIS ( magna, vestibulum, type!, convallis?, ipsum?, pulvinar?, audis?, #magna via_mollis?, #magna via_vitae?, tempor?, fugit? )

- Le champ magna constitue la clé primaire de la table. C'était déjà un identifiant de l'entité TRISTIS.
- Le champ vestibulum était déjà un simple attribut de l'entité TRISTIS.
- Un discriminateur à saisie obligatoire type est ajouté pour indiquer la nature de la spécialisation. Jamais vide, du fait de la contrainte de totalité.
- Le champ à saisie facultative convallis a migré à partir de l'entité-fille SODALES (supprimée).
- Le champ à saisie facultative ipsum a migré à partir de l'entité-fille SODALES (supprimée).
- Le champ à saisie facultative pulvinar a migré à partir de l'entité-fille NEC (supprimée).
- Le champ à saisie facultative audis a migré à partir de l'entité-fille NEC (supprimée).
- Le champ à saisie facultative magna via_mollis est une clé étrangère. Il a migré à partir de l'entité-fille NEC (supprimée) dans laquelle il avait déjà migré à partir de l'entité TRISTIS.
- Le champ à saisie facultative magna via_vitae est une clé étrangère. Il a migré à partir de l'entité-fille NEC (supprimée) dans laquelle il avait déjà migré à partir de l'entité TRISTIS.
- Le champ à saisie facultative tempor a migré à partir de l'entité-fille LACUS (supprimée).
- Le champ à saisie facultative fugit a migré à partir de l'entité-fille LACUS (supprimée).

ULTRICES ( #magna sodales, #magna lacus )

- Les champs magna sodales et magna lacus constituent la clé primaire de la table. Ce sont des clés étrangères qui ont migré directement à partir de l'entité TRISTIS.